pub enum GenerateError {
ComputeChecksum(ChecksumComputeError),
FileHasNoName,
OpenChecksumFile(ErrorKind),
CopyToPayloadFolder(ErrorKind),
StripPrefixPath(StripPrefixError),
Finalize(ErrorKind),
Payload(PayloadError),
}Expand description
Possible errors when creating bagit containers
Variants
ComputeChecksum(ChecksumComputeError)
FileHasNoName
This should not be possible, but file does not have a name
OpenChecksumFile(ErrorKind)
Failed to create directory on filesystem
CopyToPayloadFolder(ErrorKind)
Failed to read file and/or create file on filesystem
StripPrefixPath(StripPrefixError)
Failed to compute relative path of newly copied payload
Finalize(ErrorKind)
Failed to finalize bag: usually IO
Payload(PayloadError)
Payload related error